# Generated by Django 3.1.5 on 2021-01-11 21:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0011_auto_20210108_1405'),
    ]

    operations = [
        migrations.AddField(
            model_name='activity',
            name='fetched_detail',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='activity',
            name='fetched_streams',
            field=models.BooleanField(default=False),
        ),
    ]
