<!DOCTYPE html>
<html lang="en" dir="ltr">

<head>
    <meta charset="utf-8">
    {% block title %}
    <title>Success</title>
    {% endblock %}
    <!-- http://bettermotherfuckingwebsite.com/ -->
    <style type="text/css">
        body {
            margin: 40px auto;
            max-width: 650px;
            line-height: 1.6;
            font-size: 18px;
            color: #444;
            padding: 0 10px
        }

        h1,
        h2,
        h3 {
            line-height: 1.2
        }
    </style>
    {% block header %}
    {% endblock %}
</head>

<body>
    {% block body %}
    {% endblock %}
</body>

</html>