# Generated by Django 3.1.5 on 2021-01-12 05:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0013_auto_20210111_2104'),
    ]

    operations = [
        migrations.AddField(
            model_name='webhookevent',
            name='processed',
            field=models.BooleanField(default=False),
        ),
    ]
