# Generated by Django 3.1.5 on 2021-01-12 02:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0012_auto_20210111_1622'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webhookevent',
            name='updates',
            field=models.JSONField(null=True),
        ),
    ]
