# Generated by Django 3.1.5 on 2021-01-12 14:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0014_webhookevent_processed'),
    ]

    operations = [
        migrations.AlterField(
            model_name='activity',
            name='prefer_perceived_exertion',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
