# Generated by Django 3.1.5 on 2021-01-07 20:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0004_webhookevents'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='WebhookEvents',
            new_name='WebhookEvent',
        ),
    ]
