# Generated by Django 3.1.5 on 2021-01-07 03:46

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='StravaToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(max_length=1024)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='StravaAthlete',
            fields=[
                ('last_updated', models.DateTimeField(null=True)),
                ('all_data_fetched_initial', models.BooleanField(default=False)),
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('username', models.CharField(max_length=1024, null=True)),
                ('firstname', models.CharField(max_length=1024, null=True)),
                ('lastname', models.CharField(max_length=1024, null=True)),
                ('city', models.CharField(max_length=1024, null=True)),
                ('state', models.CharField(max_length=1024, null=True)),
                ('country', models.CharField(max_length=1024, null=True)),
                ('sex', models.CharField(max_length=2, null=True)),
                ('premium', models.BooleanField(default=False)),
                ('profile_medium', models.URLField(max_length=1024, null=True)),
                ('profile', models.URLField(max_length=1024, null=True)),
                ('email', models.EmailField(max_length=1024, null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='strava.stravatoken')),
            ],
        ),
        migrations.CreateModel(
            name='StravaActivity',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('external_id', models.CharField(max_length=1024, null=True)),
                ('upload_id', models.IntegerField(null=True)),
                ('name', models.CharField(max_length=1024, null=True)),
                ('distance', models.FloatField(null=True)),
                ('moving_time', models.IntegerField(null=True)),
                ('elapsed_time', models.IntegerField(null=True)),
                ('total_elevation_gain', models.FloatField(null=True)),
                ('elev_high', models.FloatField(null=True)),
                ('elev_low', models.FloatField(null=True)),
                ('start_date', models.DateTimeField(null=True)),
                ('start_date_local', models.DateTimeField(null=True)),
                ('timezone', models.CharField(max_length=1014, null=True)),
                ('achievement_count', models.IntegerField(default=0)),
                ('kudos_count', models.IntegerField(default=0)),
                ('comment_count', models.IntegerField(default=0)),
                ('athlete_count', models.IntegerField(default=0)),
                ('photo_count', models.IntegerField(default=0)),
                ('total_photo_count', models.IntegerField(default=0)),
                ('trainer', models.BooleanField(default=False)),
                ('commute', models.BooleanField(default=False)),
                ('manual', models.BooleanField(default=False)),
                ('private', models.BooleanField(default=False)),
                ('flagged', models.BooleanField(default=False)),
                ('workout_type', models.IntegerField(null=True)),
                ('average_speed', models.FloatField(null=True)),
                ('max_speed', models.FloatField(null=True)),
                ('athlete', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='strava.stravaathlete')),
            ],
        ),
    ]
