# Generated by Django 3.1.5 on 2021-01-08 05:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0008_auto_20210107_2357'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='activitystream',
            name='activity',
        ),
        migrations.RemoveField(
            model_name='activitysummary',
            name='activity',
        ),
        migrations.AddField(
            model_name='activity',
            name='achievement_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='activity',
            name='altitude',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='athlete_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='activity',
            name='average_speed',
            field=models.FloatField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='cadence',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='comment_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='activity',
            name='commute',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='activity',
            name='device_name',
            field=models.CharField(max_length=300, null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='elev_high',
            field=models.FloatField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='elev_low',
            field=models.FloatField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='flagged',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='activity',
            name='heartrate',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='kudos_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='activity',
            name='latlng',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='manual',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='activity',
            name='max_speed',
            field=models.FloatField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='photo_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='activity',
            name='private',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='activity',
            name='temp',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='time',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='timezone',
            field=models.CharField(max_length=1014, null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='total_photo_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='activity',
            name='trainer',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='activity',
            name='watts',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='activity',
            name='workout_type',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='activity',
            name='distance',
            field=models.JSONField(null=True),
        ),
        migrations.DeleteModel(
            name='ActivityDetail',
        ),
        migrations.DeleteModel(
            name='ActivityStream',
        ),
        migrations.DeleteModel(
            name='ActivitySummary',
        ),
    ]
