# Generated by Django 3.1.5 on 2021-01-07 03:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('strava', '0002_auto_20210106_2253'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stravatoken',
            name='expires_at',
            field=models.IntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='stravatoken',
            name='expires_in',
            field=models.IntegerField(null=True),
        ),
    ]
