{% extends "strava/base.html" %}


{% block body %}
        <p>
            Thanks for joining {{athlete.firstname}} {{athlete.lastname}} of {{athlete.city}}, {{athlete.state}}!
        </p>
        <p>
            <a href="{% url 'home' %}" id="home">Back to dashboard</a>.
        </p>
{% endblock %}
